; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = "QCF2_a"
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = "QCF2_b"
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = "QCF2_c"
command = ~D, DF, F, D, DF, F, c
time = 30

[Command]
name = "QCF2_x"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "QCF2_y"
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = "QCF2_z"
command = ~D, DF, F, D, DF, F, z
time = 30

[Command]
name = "QCB2_a"
command = ~D, DB, B, D, DB, B, a
time = 30

[Command]
name = "QCB2_b"
command = ~D, DB, B, D, DB, B, b
time = 30

[Command]
name = "QCB2_c"
command = ~D, DB, B, D, DB, B, c
time = 30

[Command]
name = "QCB2_x"
command = ~D, DB, B, D, DB, B, x
time = 30

[Command]
name = "QCB2_y"
command = ~D, DB, B, D, DB, B, y
time = 30

[Command]
name = "QCB2_z"
command = ~D, DB, B, D, DB, B, z
time = 30

[Command]
name = "QCBHCF_z"
command = ~D, DB, B, D, DF F, z
time = 40


;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "HATE"
command = ~D, DF, F, s

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z



[Command]
name = "RDP_x"
command = ~B, D, DB, x

[Command]
name = "RDP_z"
command = ~B, D, DB, z

[Command]
name = "RDP_y"
command = ~B, D, DB, y

[Command]
name = "RDP_a"
command = ~B, D, DB, a

[Command]
name = "RDP_b"
command = ~B, D, DB, b

[Command]
name = "RDP_c"
command = ~B, D, DB, c

[Command]
name = "DP_a"
command = ~F, D, DF, a

[Command]
name = "DP_b"
command = ~F, D, DF, b

[Command]
name = "DP_c"
command = ~F, D, DF, c

[Command]
name = "DP_x"
command = ~F, D, DF, x

[Command]
name = "DP_y"
command = ~F, D, DF, y

[Command]
name = "DP_z"
command = ~F, D, DF, z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"      ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"       ;Required (do not remove)
command = B, B
time = 10
;---------------------------------------------------------------------------
[Command]
name = "BF_a"
command = $B, F, a

[Command]
name = "BF_b"
command = $B, F, b

[Command]
name = "BF_c"
command = $B, F, c

[Command]
name = "FB_a"
command = $F, B, a

[Command]
name = "FB_b"
command = $F, B, b

[Command]
name = "FB_c"
command = $F, B, c

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "bc"
command = b+c
time = 1

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "yz"
command = y+z
time = 1

[Command]
name = "xyz"
command = x+y+z
time = 1

[Command]
name = "abc"
command = a+b+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "downfwd_a"
command = /DF,a
time = 1

[Command]
name = "downfwd_b"
command = /DF,b
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s ;	Start!
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd"  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup"   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
Superwaza Ac
[State -1]
type = ChangeState
value = 3000
trigger1 = power = 3000
trigger1 = command = "QCB2_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
Superwaza Ab
[State -1]
type = ChangeState
value = 3900
trigger1 = power >= 2000
trigger1 = command = "QCB2_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
Superwaza Aa
[State -1]
type = ChangeState
value = 3920
trigger1 = power >= 1000
trigger1 = command = "QCB2_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Superwaza Ba
[State -1]
type = ChangeState
value = 3160
triggerall = power = 3000
triggerall = command = "QCF2_c"
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Superwaza Bb
[State -1]
type = ChangeState
value = 3150
triggerall = power >= 2000
triggerall = command = "QCF2_b"
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
Superwaza Bc
[State -1]
type = ChangeState
value = 3140
triggerall = power >= 1000
triggerall = command = "QCF2_a"
trigger1 = ctrl = 1
;===========================================================================
;---------------------------------------------------------------------------
;WazaA_a
[State -1]
type = ChangeState
value = 1000
triggerall = command = "BF_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = power = 3000
trigger6 = movecontact = 1
trigger6 = stateno = [0, 1199]
;---------------------------------------------------------------------------
;WazaA_b
[State -1]
type = ChangeState
value = 1010
triggerall = command = "BF_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = power = 3000
trigger6 = movecontact = 1
trigger6 = stateno = [0, 1199]
;---------------------------------------------------------------------------
;WazaA_c
[State -1]
type = ChangeState
value = 1020
triggerall = command = "BF_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = power = 3000
trigger6 = movecontact = 1
trigger6 = stateno = [0, 1199]
;---------------------------------------------------------------------------
;Panic Duck
[State -1]
type = ChangeState
value = 1100
triggerall = command = "FB_a"
trigger1 = Statetype = S
trigger1 = ctrl = 1
trigger2 = anim = 5002
trigger3 = power = 3000
trigger3 = movetype = H
;---------------------------------------------------------------------------
;Panic Duck
[State -1]
type = ChangeState
value = 1120
triggerall = command = "FB_b"
trigger1 = Statetype = S
trigger1 = ctrl = 1
trigger2 = anim = 5002
trigger3 = power = 3000
trigger3 = movetype = H
;---------------------------------------------------------------------------
;Panic Duck
[State -1]
type = ChangeState
value = 1130
triggerall = command = "FB_c"
trigger1 = Statetype = S
trigger1 = ctrl = 1
trigger2 = anim = 5002
trigger3 = power = 3000
trigger3 = movetype = H
;---------------------------------------------------------------------------
;JAB PSYCHO CHUCK STUFF
[State - 1]
type = ChangeState
value = 1140
trigger1 = command = "QCF_a"
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;STRONG PSYCHO CHUCK STUFF
[State - 1]
type = ChangeState
value = 1150
trigger1 = command = "QCF_b"
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;FIERCE PSYCHO CHUCK STUFF
[State - 1]
type = ChangeState
value = 1160
trigger1 = command = "QCF_c"
trigger1 = ctrl = 1
;-----------------------------------------------------------------------
;---------------------------------------------------------------------------
;JAB PSYCHO THROW
[State - 1]
type = ChangeState
value = 1300
triggerall = command = "QCB_a"
trigger1 = Statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = stateno = 401 ;crouch A combo
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 400 ;crouch A
trigger8 = movecontact = 1
trigger9 = stateno = 420 ;crouch C
trigger9 = movecontact = 1
;---------------------------------------------------------------------------
;STRONG PSYCHO THROW
[State - 1]
type = ChangeState
value = 1301
triggerall = command = "QCB_b"
trigger1 = Statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = stateno = 401 ;crouch A combo
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 400 ;crouch A
trigger8 = movecontact = 1
trigger9 = stateno = 420 ;crouch C
trigger9 = movecontact = 1
;---------------------------------------------------------------------------
;FIERCE PSYCHO THROW
[State - 1]
type = ChangeState
value = 1302
triggerall = command = "QCB_c"
trigger1 = Statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = stateno = 401 ;crouch A combo
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 400 ;crouch A
trigger8 = movecontact = 1
trigger9 = stateno = 420 ;crouch C
trigger9 = movecontact = 1
;-----------------------------------------------------------------------
;HATE YOUR FRIENDS
[State - 1]
type = ChangeState
value = 1165
triggerall = command = "HATE"
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 220 
trigger5 = movecontact = 1
trigger6 = stateno = 401 ;crouch A combo
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 400 ;crouch A
trigger8 = movecontact = 1
trigger9 = stateno = 420 ;crouch C
trigger9 = movecontact = 1
;------------------------------------------------------------------------
;CONFUSION ATTACK
[State - 1]
type = ChangeState
value = 1200
trigger1 = command = "QCB_x"
trigger1 = Statetype = S
trigger1 = ctrl = 1
;-----------------------------------------------------------------------
;CONFUSION ATTACK
[State - 1]
type = ChangeState
value = 1201
trigger1 = command = "QCB_y"
trigger1 = Statetype = S
trigger1 = ctrl = 1
;-----------------------------------------------------------------------
;CONFUSION ATTACK
[State - 1]
type = ChangeState
value = 1202
trigger1 = command = "QCB_z"
trigger1 = Statetype = S
trigger1 = ctrl = 1
;--------------------------------------------------------------------------
;DISABLE ATTACK
[State -1]
type = ChangeState
value = 1262
trigger1 = command = "QCF_x"
trigger1 = Statetype = S
trigger1 = ctrl = 1
;--------------------------------------------------------------------------
;DISABLE ATTACK
[State -1]
type = ChangeState
value = 1263
trigger1 = command = "QCF_y"
trigger1 = Statetype = S
trigger1 = ctrl = 1
;--------------------------------------------------------------------------
;DISABLE ATTACK
[State -1]
type = ChangeState
value = 1264
trigger1 = command = "QCF_z"
trigger1 = Statetype = S
trigger1 = ctrl = 1
;===========================================================================
;EXPERIMENT
[State - 1]
type = ChangeState
value = 10000
trigger1 = command = "xy"
trigger1 = ctrl = 1
trigger1 = statetype = S
;-------------------------
;EXPERIMENT
[State - 1]
type = ChangeState
value = 10001
trigger1 = command = "yz"
trigger1 = ctrl = 1
trigger1 = statetype = S
;-------------------------
;EXPERIMENT
[State -1]
type = ChangeState
value = 10002
trigger1 = command = "y"
trigger1 = ctrl = 1
trigger1 = statetype = S
;-------------------------
;EXPERIMENT
[State -1]
type = ChangeState
value = 10003
trigger1 = command = "x"
trigger1 = ctrl = 1
trigger1 = statetype = S
;---------------------------------------------------------------------------
;-----------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw
[State -1]
type = ChangeState
value = 290
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "fwd_c" ;Command
trigger1 = p2bodydist X < 4
trigger1 = p2statetype = S
trigger1 = p2movetype != H
;===========================================================================
[State -1]
type = Changestate
value = 1180
trigger1 = command = "start"
trigger1 = ctrl = 1
trigger1 = power != 3000
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
trigger1 = command = "a"
trigger1 = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = command = "a"
trigger2 = command != "holddown"
trigger2 = statetype = S
trigger2 = movecontact = 1
trigger2 = stateno = 201
;--------------------------------------------------------------------------
;Stand_A PART 2
[State -1]
type = ChangeState
value = 201
trigger1 = command = "a"
trigger1 = command != "holddown"
trigger1 = statetype = S
trigger1 = stateno = 200
trigger1 = movecontact = 1
;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1
trigger3 = power = 3000
trigger3 = statetype != A
trigger3 = ctrl = 1
trigger3 = movecontact = 1
trigger3 = stateno = [0, 1160]
;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 220
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = power = 3000
trigger4 = ctrl = 1
trigger4 = statetype != A
trigger4 = movecontact = 1
trigger4 = stateno = [0, 1160]
;----------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = command = "a"
trigger2 = command = "holddown"
trigger2 = statetype = C
trigger2 = movecontact = 1
trigger2 = stateno = 401
;--------------------------------------------------------------------------
;Crouch_A COMBO
[State -1]
type = ChangeState
value = 401
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = stateno = 400
trigger1 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 401 ;crouch A
trigger2 = movecontact = 1
trigger3 = stateno = 201 ;Stand combo A
trigger3 = movecontact = 1
trigger4 = power = 3000
trigger4 = statetype != A
trigger4 = ctrl = 1
trigger4 = movecontact = 1
trigger4 = stateno = [0,1160]
;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 420
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 401 ;crouch A combo
trigger2 = movecontact = 1
trigger3 = stateno = 201 ;Stand combo A
trigger3 = movecontact = 1
trigger4 = stateno = 410
trigger4 = movecontact = 1
trigger5 = stateno = 400 ;crouch A
trigger5 = movecontact = 1
trigger6 = power = 3000
trigger6 = statetype != A
trigger6 = ctrl = 1
trigger6 = movecontact = 1
trigger6 = stateno = [0, 1160]
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "a"  ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6
trigger3 = power = 3000
trigger3 = ctrl = 1
trigger3 = movecontact = 1
trigger3 = stateno = [600, 610]
;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b"   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1
trigger3 = power = 3000
trigger3 = ctrl = 1
trigger3 = movecontact = 1
trigger3 = stateno = [600, 610]
;---------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 620
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b"   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1
trigger3 = command = "c"
trigger3 = stateno = 610
trigger3 = movecontact = 1
